@@ -24,10 +24,10 @@
 #' @export
 check_site_models <- function(site_models) {
 
-  if (is_site_model(site_models)) { # nolint beautier function
+  if (beautier::is_site_model(site_models)) {
     site_models <- list(site_models)
   }
-  if (!are_site_models(site_models)) { # nolint beautier function
+  if (!beautier::are_site_models(site_models)) {
     stop(
       "'site_models' must be a list of one or more valid site models. ",
       "Actual value(s): ", site_models
