@@ -9,16 +9,16 @@ clock_model_to_xml_operators <- function(
   mrca_priors,
   tipdates_filename = NA
 ) {
-  testit::assert(is_clock_model(clock_model)) # nolint beautier function
+  testit::assert(beautier::is_clock_model(clock_model))
   id <- clock_model$id
 
   # May not need ID at all, if it is the first and strict clock model
   text <- NULL
-  if (!is_strict_clock_model(clock_model)) { # nolint beautier function
+  if (!beautier::is_strict_clock_model(clock_model)) {
     # Will fail on unimplemented clock models
-    testit::assert(is_rln_clock_model(clock_model)) # nolint beautier function
+    testit::assert(beautier::is_rln_clock_model(clock_model))
 
-    testit::assert(is_id(id)) # nolint beautier function
+    testit::assert(beautier::is_id(id))
     text <- c(text, paste0("<operator id=\"ucldStdevScaler.c:", id, "\" ",
       "spec=\"ScaleOperator\" parameter=\"@ucldStdev.c:", id, "\" ",
       "scaleFactor=\"0.5\" weight=\"3.0\"/>")) # nolint this is no absolute path
@@ -53,8 +53,9 @@ clock_model_to_xml_operators <- function(
     }
   }
 
-  if ((is_strict_clock_model(clock_model) && is_mrca_prior_with_distr(mrca_priors[[1]])) || # nolint
-      !is_one_na(tipdates_filename) # nolint beautier function
+  if ((beautier::is_strict_clock_model(clock_model)
+    && beautier::is_mrca_prior_with_distr(mrca_priors[[1]])) ||
+      !beautier::is_one_na(tipdates_filename)
   ) {
     text <- c(
       text,
