@@ -2,7 +2,7 @@
 #' @inheritParams default_params_doc
 #' @return a character vector of XML strings
 #' @seealso the complete tracelog section is created
-#'   by \code{\link{create_beast2_input_tracelog}}
+#'   by \code{\link{create_tracelog_xml}}
 #' @examples
 #' # <logger id="tracelog" ...>
 #' #'   # Here
@@ -13,12 +13,12 @@ clock_models_to_xml_tracelog <- function(
   clock_models,
   mrca_priors = NA
 ) {
-  testit::assert(are_clock_models(clock_models)) # nolint beautier function
+  testit::assert(beautier::are_clock_models(clock_models))
 
   text <- NULL
   for (i in seq_along(clock_models)) {
     clock_model <- clock_models[[i]]
-    testit::assert(is_clock_model(clock_model)) # nolint beautier function
+    testit::assert(beautier::is_clock_model(clock_model))
     text <- c(
       text,
       clock_model_to_xml_tracelog( # nolint beautier function
