@@ -2,7 +2,7 @@
 #' @inheritParams default_params_doc
 #' @return lines of XML text
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 create_beast2_input_operators <- function( # nolint beautier function
   site_models,
   clock_models,
@@ -11,11 +11,11 @@ create_beast2_input_operators <- function( # nolint beautier function
   mrca_priors = NA,
   tipdates_filename = NA
 ) {
-  testit::assert(is.logical(fixed_crown_ages))
-  testit::assert(are_site_models(site_models)) # nolint beautier function
-  testit::assert(are_clock_models(clock_models)) # nolint beautier function
-  testit::assert(are_tree_priors(tree_priors)) # nolint beautier function
-  testit::assert(are_mrca_priors(mrca_priors)) # nolint beautier function
+  testit::assert(beautier::is_one_bool(fixed_crown_ages))
+  testit::assert(beautier::are_site_models(site_models))
+  testit::assert(beautier::are_clock_models(clock_models))
+  testit::assert(beautier::are_tree_priors(tree_priors))
+  testit::assert(beautier::are_mrca_priors(mrca_priors))
   testit::assert(length(site_models) == length(fixed_crown_ages))
 
   text <- NULL
@@ -38,7 +38,7 @@ create_beast2_input_operators <- function( # nolint beautier function
       tipdates_filename = tipdates_filename
     )
   )
-  text <- interspace(text) # nolint beautier function
+  text <- beautier::interspace(text)
 
-  indent(text, n_spaces = 4) # nolint beautier function
+  beautier::indent(text)
 }
