@@ -38,6 +38,6 @@ create_inference_model <- function(
     beauti_options = beauti_options,
     tipdates_filename = tipdates_filename
   )
-  check_inference_model(inference_model) # nolint beautier function
+  beautier::check_inference_model(inference_model)
   inference_model
 }
