@@ -17,10 +17,10 @@
 #' @export
 create_tree_priors <- function() {
   list(
-    beautier::create_bd_tree_prior(), # nolint beautier function
-    beautier::create_cbs_tree_prior(), # nolint beautier function
-    beautier::create_ccp_tree_prior(), # nolint beautier function
-    beautier::create_cep_tree_prior(), # nolint beautier function
-    beautier::create_yule_tree_prior() # nolint beautier function
+    beautier::create_bd_tree_prior(),
+    beautier::create_cbs_tree_prior(),
+    beautier::create_ccp_tree_prior(),
+    beautier::create_cep_tree_prior(),
+    beautier::create_yule_tree_prior()
   )
 }
