@@ -2,12 +2,12 @@
 #' @param lines lines of text
 #' @return lines of text from the first to and including the last operators line
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 extract_xml_loggers_from_lines <- function( # nolint beautier function
   lines
 ) {
-  first_line <- find_first_regex_line(lines, "<logger id=\"") # nolint beautier function
-  testit::assert(!is_one_na(first_line)) # nolint beautier function
-  last_line <- find_last_regex_line(lines, "</logger>") # nolint beautier function
+  first_line <- beautier::find_first_regex_line(lines, "<logger id=\"")
+  testit::assert(!beautier::is_one_na(first_line))
+  last_line <- beautier::find_last_regex_line(lines, "</logger>")
   lines[first_line:last_line]
 }
