@@ -6,7 +6,7 @@
 get_clock_models_ids <- function(
   clock_models
 ) {
-  testit::assert(are_clock_models(clock_models)) # nolint beautier function
+  testit::assert(beautier::are_clock_models(clock_models))
   n <- length(clock_models)
   ids <- rep(NA, n)
   for (i in seq_along(clock_models)) {
