@@ -15,12 +15,12 @@
 get_tree_priors_n_params <- function(
   tree_priors
 ) {
-  if (!are_tree_priors(tree_priors)) { # nolint beautier function
+  if (!beautier::are_tree_priors(tree_priors)) {
     stop("'tree_priors' must be a list of tree priors")
   }
   n <- 0
   for (tree_prior in tree_priors) {
-    n <- n + get_tree_prior_n_params(tree_prior) # nolint beautier function
+    n <- n + beautier::get_tree_prior_n_params(tree_prior)
   }
   n
 }
