@@ -11,10 +11,8 @@ has_xml_closing_tag <- function(
   lines,
   section
 ) {
-  if (!is.character(section)) {
-    stop("'section' must be a word")
-  }
-  !is_one_na( # nolint beautier function
+  assertive::assert_is_a_string(section)
+  !beautier::is_one_na(
     find_last_xml_closing_tag_line(
       lines = lines,
       section = section
