@@ -22,7 +22,7 @@ has_xml_short_closing_tag <- function(
         pattern = "/>" # nolint this is no absolute path
       )
     )
-    if (!is_one_na(match)) return(TRUE) # nolint beautier function
+    if (!beautier::is_one_na(match)) return(TRUE)
   }
   FALSE
 }
