@@ -11,27 +11,27 @@ init_site_models <- function(
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(are_site_models(site_models)) # nolint beautier function
+  testit::assert(beautier::are_site_models(site_models))
   testit::assert(length(site_models) == length(ids))
 
   for (i in seq_along(site_models)) {
     site_model <- site_models[[i]]
-    testit::assert(is_site_model(site_model)) # nolint beautier function
-    if (is_gtr_site_model(site_model)) { # nolint beautier function
+    testit::assert(beautier::is_site_model(site_model))
+    if (beautier::is_gtr_site_model(site_model)) {
       # GTR
-      site_model <- init_gtr_site_model( # nolint beautier function call
+      site_model <- beautier::init_gtr_site_model(
         site_model,
         distr_id = distr_id,
         param_id = param_id
       )
-    } else if (is_hky_site_model(site_model)) { # nolint beautier function
+    } else if (beautier::is_hky_site_model(site_model)) {
       # HKY
       site_model <- init_hky_site_model( # nolint beautier function call
         site_model,
         distr_id = distr_id,
         param_id = param_id
       )
-    } else if (is_jc69_site_model(site_model)) { # nolint beautier function
+    } else if (beautier::is_jc69_site_model(site_model)) {
       # JC69
       site_model <- init_jc69_site_model( # nolint beautier function call
         site_model,
@@ -39,7 +39,7 @@ init_site_models <- function(
         param_id = param_id
       )
     } else {
-      testit::assert(is_tn93_site_model(site_model)) # nolint beautier function
+      testit::assert(beautier::is_tn93_site_model(site_model))
       site_model <- init_tn93_site_model( # nolint beautier function call
         site_model,
         distr_id = distr_id,
@@ -47,11 +47,11 @@ init_site_models <- function(
       )
     }
 
-    distr_id <- distr_id + get_site_model_n_distrs(site_model) # nolint beautier function
-    param_id <- param_id + get_site_model_n_params(site_model) # nolint beautier function
+    distr_id <- distr_id + beautier::get_site_model_n_distrs(site_model)
+    param_id <- param_id + beautier::get_site_model_n_params(site_model)
 
-    if (is_one_na(site_model$id)) site_model$id <- ids[i] # nolint beautier function call
-    testit::assert(is_init_site_model(site_model)) # nolint beautier function call
+    if (beautier::is_one_na(site_model$id)) site_model$id <- ids[i]
+    testit::assert(beautier::is_init_site_model(site_model))
     site_models[[i]] <- site_model
   }
   site_models
@@ -63,26 +63,36 @@ init_site_models <- function(
 #' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   gtr_site_model <- create_gtr_site_model()
-#'   testit::assert(!beautier:::is_init_gtr_site_model(gtr_site_model))
-#'   gtr_site_model <- beautier:::init_gtr_site_model(gtr_site_model)
-#'   testit::assert(beautier:::is_init_gtr_site_model(gtr_site_model))
+#'   testit::assert(!is_init_gtr_site_model(gtr_site_model))
+#'   gtr_site_model <- init_gtr_site_model(gtr_site_model)
+#'   testit::assert(is_init_gtr_site_model(gtr_site_model))
+#' @export
 init_gtr_site_model <- function(
   gtr_site_model,
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(is_gtr_site_model(gtr_site_model)) # nolint beautier function
+  testit::assert(beautier::is_gtr_site_model(gtr_site_model))
 
   # Initialize gamma site model, if any
-  if (!is_one_na(gtr_site_model$gamma_site_model$gamma_shape_prior_distr)) { # nolint beautier function
-    if (!is_init_distr(gtr_site_model$gamma_site_model$gamma_shape_prior_distr)) { # nolint beautier function
-      gtr_site_model$gamma_site_model$gamma_shape_prior_distr <- init_distr( # nolint beautier function
+  if (
+    !beautier::is_one_na(
+      gtr_site_model$gamma_site_model$gamma_shape_prior_distr
+    )
+  ) {
+    if (
+      !beautier::is_init_distr(
+        gtr_site_model$gamma_site_model$gamma_shape_prior_distr
+      )
+    ) {
+      gtr_site_model$gamma_site_model$gamma_shape_prior_distr <-
+        beautier::init_distr(
         gtr_site_model$gamma_site_model$gamma_shape_prior_distr,
         distr_id = distr_id,
         param_id = param_id
       )
       distr_id <- distr_id + 1
-      param_id <- param_id + get_distr_n_params( # nolint beautier function
+      param_id <- param_id + beautier::get_distr_n_params(
         gtr_site_model$gamma_site_model$gamma_shape_prior_distr
       )
     }
@@ -95,7 +105,7 @@ init_gtr_site_model <- function(
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       gtr_site_model$rate_ac_prior_distr
     )
   }
@@ -106,7 +116,7 @@ init_gtr_site_model <- function(
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       gtr_site_model$rate_ag_prior_distr
     )
   }
@@ -117,7 +127,7 @@ init_gtr_site_model <- function(
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       gtr_site_model$rate_at_prior_distr
     )
   }
@@ -128,65 +138,67 @@ init_gtr_site_model <- function(
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       gtr_site_model$rate_cg_prior_distr
     )
   }
-  if (!is_init_distr(gtr_site_model$rate_gt_prior_distr)) { # nolint beautier function
-    gtr_site_model$rate_gt_prior_distr <- init_distr( # nolint beautier function
+  if (!beautier::is_init_distr(gtr_site_model$rate_gt_prior_distr)) {
+    gtr_site_model$rate_gt_prior_distr <- beautier::init_distr(
       gtr_site_model$rate_gt_prior_distr,
       distr_id = distr_id,
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       gtr_site_model$rate_gt_prior_distr
     )
   }
-  if (!is_init_param(gtr_site_model$rate_ac_param)) { # nolint beautier function
-    gtr_site_model$rate_ac_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(gtr_site_model$rate_ac_param)) {
+    gtr_site_model$rate_ac_param <- beautier::init_param(
       gtr_site_model$rate_ac_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
-  if (!is_init_param(gtr_site_model$rate_ag_param)) { # nolint beautier function
-    gtr_site_model$rate_ag_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(gtr_site_model$rate_ag_param)) {
+    gtr_site_model$rate_ag_param <- beautier::init_param(
       gtr_site_model$rate_ag_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
-  if (!is_init_param(gtr_site_model$rate_at_param)) { # nolint beautier function
-    gtr_site_model$rate_at_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(gtr_site_model$rate_at_param)) {
+    gtr_site_model$rate_at_param <- beautier::init_param(
       gtr_site_model$rate_at_param, id = param_id
     )
     param_id <- param_id + 1
   }
-  if (!is_init_param(gtr_site_model$rate_cg_param)) { # nolint beautier function
-    gtr_site_model$rate_cg_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(gtr_site_model$rate_cg_param)) {
+    gtr_site_model$rate_cg_param <- beautier::init_param(
       gtr_site_model$rate_cg_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
-  if (!is_init_param(gtr_site_model$rate_ct_param)) { # nolint beautier function
-    gtr_site_model$rate_ct_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(gtr_site_model$rate_ct_param)) {
+    gtr_site_model$rate_ct_param <- beautier::init_param(
       gtr_site_model$rate_ct_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
-  if (!is_init_param(gtr_site_model$rate_gt_param)) { # nolint beautier function
-    gtr_site_model$rate_gt_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(gtr_site_model$rate_gt_param)) {
+    gtr_site_model$rate_gt_param <- beautier::init_param(
       gtr_site_model$rate_gt_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
-  testit::assert(is_gtr_site_model(gtr_site_model)) # nolint beautier function
-  testit::assert(is_init_gamma_site_model(gtr_site_model$gamma_site_model)) # nolint beautier function
-  testit::assert(is_init_gtr_site_model(gtr_site_model)) # nolint beautier function
+  testit::assert(beautier::is_gtr_site_model(gtr_site_model))
+  testit::assert(
+    beautier::is_init_gamma_site_model(gtr_site_model$gamma_site_model)
+  )
+  testit::assert(beautier::is_init_gtr_site_model(gtr_site_model))
   gtr_site_model
 }
 
@@ -204,40 +216,47 @@ init_hky_site_model <- function(
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(is_hky_site_model(hky_site_model)) # nolint beautier function
+  testit::assert(beautier::is_hky_site_model(hky_site_model))
 
   # Initialize gamma site model, if any
-  if (!is_one_na(hky_site_model$gamma_site_model$gamma_shape_prior_distr)) { # nolint beautier function
-    if (!is_init_distr( # nolint beautier function
+  if (
+    !beautier::is_one_na(
+      hky_site_model$gamma_site_model$gamma_shape_prior_distr
+    )
+  ) {
+    if (!beautier::is_init_distr(
       hky_site_model$gamma_site_model$gamma_shape_prior_distr
     )) {
-      hky_site_model$gamma_site_model$gamma_shape_prior_distr <- init_distr( # nolint beautier function
+      hky_site_model$gamma_site_model$gamma_shape_prior_distr <-
+        beautier::init_distr(
         hky_site_model$gamma_site_model$gamma_shape_prior_distr,
         distr_id = distr_id,
         param_id = param_id
       )
       distr_id <- distr_id + 1
-      param_id <- param_id + get_distr_n_params( # nolint beautier function
+      param_id <- param_id + beautier::get_distr_n_params(
         hky_site_model$gamma_site_model$gamma_shape_prior_distr
       )
     }
   }
 
   # kappa_prior_distr
-  if (!is_init_distr(hky_site_model$kappa_prior_distr)) { # nolint beautier function
-    hky_site_model$kappa_prior_distr <- init_distr( # nolint beautier function
+  if (!beautier::is_init_distr(hky_site_model$kappa_prior_distr)) {
+    hky_site_model$kappa_prior_distr <- beautier::init_distr(
       hky_site_model$kappa_prior_distr,
       distr_id = distr_id,
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       hky_site_model$kappa_prior_distr
     )
   }
 
-  testit::assert(is_init_gamma_site_model(hky_site_model$gamma_site_model)) # nolint beautier function
-  testit::assert(is_init_hky_site_model(hky_site_model)) # nolint beautier function
+  testit::assert(
+    beautier::is_init_gamma_site_model(hky_site_model$gamma_site_model)
+  )
+  testit::assert(beautier::is_init_hky_site_model(hky_site_model))
   hky_site_model
 }
 
@@ -251,32 +270,42 @@ init_hky_site_model <- function(
 #'   testit::assert(!beautier:::is_init_hky_site_model(hky_site_model))
 #'   hky_site_model <- beautier:::init_hky_site_model(hky_site_model)
 #'   testit::assert(beautier:::is_init_hky_site_model(hky_site_model))
+#' @export
 init_jc69_site_model <- function(
   jc69_site_model,
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(is_jc69_site_model(jc69_site_model)) # nolint beautier function
+  testit::assert(beautier::is_jc69_site_model(jc69_site_model))
 
   # Initialize gamma site model, if any
-  if (!is_one_na(jc69_site_model$gamma_site_model$gamma_shape_prior_distr)) { # nolint beautier function
+  if (
+    !beautier::is_one_na(
+      jc69_site_model$gamma_site_model$gamma_shape_prior_distr
+    )
+  ) {
     if (
-      !is_init_distr(jc69_site_model$gamma_site_model$gamma_shape_prior_distr) # nolint beautier function
+      !beautier::is_init_distr(
+        jc69_site_model$gamma_site_model$gamma_shape_prior_distr
+      )
     ) {
-      jc69_site_model$gamma_site_model$gamma_shape_prior_distr <- init_distr( # nolint beautier function
+      jc69_site_model$gamma_site_model$gamma_shape_prior_distr <-
+        beautier::init_distr(
         jc69_site_model$gamma_site_model$gamma_shape_prior_distr,
         distr_id = distr_id,
         param_id = param_id
       )
       distr_id <- distr_id + 1
-      param_id <- param_id + get_distr_n_params( # nolint beautier function
+      param_id <- param_id + beautier::get_distr_n_params(
         jc69_site_model$gamma_site_model$gamma_shape_prior_distr
       )
     }
   }
 
-  testit::assert(is_init_gamma_site_model(jc69_site_model$gamma_site_model)) # nolint beautier function
-  testit::assert(is_init_jc69_site_model(jc69_site_model)) # nolint beautier function
+  testit::assert(
+    beautier::is_init_gamma_site_model(jc69_site_model$gamma_site_model)
+  )
+  testit::assert(beautier::is_init_jc69_site_model(jc69_site_model))
   jc69_site_model
 }
 
@@ -287,76 +316,88 @@ init_jc69_site_model <- function(
 #' @return an initialized TN93 site model
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#'   tn93_site_model <- create_tn93_site_model()
-#'   testit::assert(!beautier:::is_init_tn93_site_model(tn93_site_model))
-#'   tn93_site_model <- beautier:::init_tn93_site_model(tn93_site_model)
-#'   testit::assert(beautier:::is_init_tn93_site_model(tn93_site_model))
+#' library(testthat)
+#'
+#' tn93_site_model <- create_tn93_site_model()
+#' expect_false(is_init_tn93_site_model(tn93_site_model))
+#' tn93_site_model <- init_tn93_site_model(tn93_site_model)
+#' expect_true(is_init_tn93_site_model(tn93_site_model))
+#' @export
 init_tn93_site_model <- function(
   tn93_site_model,
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(is_tn93_site_model(tn93_site_model)) # nolint beautier function
+  testit::assert(beautier::is_tn93_site_model(tn93_site_model))
 
   # Initialize gamma site model, if any
-  if (!is_one_na(tn93_site_model$gamma_site_model$gamma_shape_prior_distr)) { # nolint beautier function
+  if (
+    !beautier::is_one_na(
+      tn93_site_model$gamma_site_model$gamma_shape_prior_distr
+    )
+  ) {
     if (
-      !is_init_distr(tn93_site_model$gamma_site_model$gamma_shape_prior_distr) # nolint beautier function
+      !beautier::is_init_distr(
+        tn93_site_model$gamma_site_model$gamma_shape_prior_distr
+      )
     ) {
-      tn93_site_model$gamma_site_model$gamma_shape_prior_distr <- init_distr( # nolint beautier function
+      tn93_site_model$gamma_site_model$gamma_shape_prior_distr <-
+        beautier::init_distr(
         tn93_site_model$gamma_site_model$gamma_shape_prior_distr,
         distr_id = distr_id,
         param_id = param_id
       )
       distr_id <- distr_id + 1
-      param_id <- param_id + get_distr_n_params( # nolint beautier function
+      param_id <- param_id + beautier::get_distr_n_params(
         tn93_site_model$gamma_site_model$gamma_shape_prior_distr
       )
     }
   }
 
   # kappa_1_prior_distr
-  if (!is_init_distr(tn93_site_model$kappa_1_prior_distr)) { # nolint beautier function
-    tn93_site_model$kappa_1_prior_distr <- init_distr( # nolint beautier function
+  if (!beautier::is_init_distr(tn93_site_model$kappa_1_prior_distr)) {
+    tn93_site_model$kappa_1_prior_distr <- beautier::init_distr(
       tn93_site_model$kappa_1_prior_distr,
       distr_id = distr_id,
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       tn93_site_model$kappa_1_prior_distr
     )
   }
 
   # kappa_2_prior_distr
-  if (!is_init_distr(tn93_site_model$kappa_2_prior_distr)) { # nolint beautier function
-    tn93_site_model$kappa_2_prior_distr <- init_distr( # nolint beautier function
+  if (!beautier::is_init_distr(tn93_site_model$kappa_2_prior_distr)) {
+    tn93_site_model$kappa_2_prior_distr <- beautier::init_distr(
       tn93_site_model$kappa_2_prior_distr,
       distr_id = distr_id,
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + get_distr_n_params( # nolint beautier function
+    param_id <- param_id + beautier::get_distr_n_params(
       tn93_site_model$kappa_2_prior_distr
     )
   }
 
-  if (!is_init_param(tn93_site_model$kappa_1_param)) { # nolint beautier function
-    tn93_site_model$kappa_1_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(tn93_site_model$kappa_1_param)) {
+    tn93_site_model$kappa_1_param <- beautier::init_param(
       tn93_site_model$kappa_1_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
 
-  if (!is_init_param(tn93_site_model$kappa_2_param)) { # nolint beautier function
-    tn93_site_model$kappa_2_param <- init_param( # nolint beautier function
+  if (!beautier::is_init_param(tn93_site_model$kappa_2_param)) {
+    tn93_site_model$kappa_2_param <- beautier::init_param(
       tn93_site_model$kappa_2_param,
       id = param_id
     )
     param_id <- param_id + 1
   }
-  testit::assert(is_init_gamma_site_model(tn93_site_model$gamma_site_model)) # nolint beautier function
-  testit::assert(is_init_tn93_site_model(tn93_site_model)) # nolint beautier function
+  testit::assert(
+    beautier::is_init_gamma_site_model(tn93_site_model$gamma_site_model)
+  )
+  testit::assert(beautier::is_init_tn93_site_model(tn93_site_model))
   tn93_site_model
 }
