@@ -5,10 +5,10 @@
 #' @examples
 #'   gamma_site_model <- create_gamma_site_model()
 #'   testit::assert(beautier:::is_gamma_site_model(gamma_site_model))
-#' @noRd
+#' @export
 is_gamma_site_model <- function(x) {
   tryCatch({
-      check_gamma_site_model(x) # nolint beautier function
+      beautier::check_gamma_site_model(x)
       TRUE
     },
     error = function(e) { # nolint indeed ignore e
