@@ -4,34 +4,34 @@
 #'   initialized distribution object
 #' @return TRUE if x is an initialized distribution object
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_distr <- function(
   x
 ) {
-  if (!is_distr(x)) return(FALSE) # nolint beautier function
-  if (is_one_na(x$id)) return(FALSE) # nolint beautier function
+  if (!beautier::is_distr(x)) return(FALSE)
+  if (beautier::is_one_na(x$id)) return(FALSE)
 
-  if (is_beta_distr(x)) { # nolint beautier function
-    return(is_init_beta_distr(x))  # nolint beautier function call
-  } else if (is_exp_distr(x)) { # nolint beautier function
-    return(is_init_exp_distr(x))  # nolint beautier function call
-  } else if (is_gamma_distr(x)) { # nolint beautier function
-    return(is_init_gamma_distr(x))  # nolint beautier function call
-  } else if (is_inv_gamma_distr(x)) { # nolint beautier function
-    return(is_init_inv_gamma_distr(x))  # nolint beautier function call
-  } else if (is_laplace_distr(x)) { # nolint beautier function
-    return(is_init_laplace_distr(x))  # nolint beautier function call
-  } else if (is_log_normal_distr(x)) { # nolint beautier function
-    return(is_init_log_normal_distr(x))  # nolint beautier function call
-  } else if (is_normal_distr(x)) { # nolint beautier function
-    return(is_init_normal_distr(x))  # nolint beautier function call
-  } else if (is_one_div_x_distr(x)) { # nolint beautier function
-    return(is_init_one_div_x_distr(x))  # nolint beautier function call
-  } else if (is_poisson_distr(x)) { # nolint beautier function
-    return(is_init_poisson_distr(x))  # nolint beautier function call
+  if (beautier::is_beta_distr(x)) {
+    return(beautier::is_init_beta_distr(x))
+  } else if (beautier::is_exp_distr(x)) {
+    return(beautier::is_init_exp_distr(x))
+  } else if (beautier::is_gamma_distr(x)) {
+    return(beautier::is_init_gamma_distr(x))
+  } else if (beautier::is_inv_gamma_distr(x)) {
+    return(beautier::is_init_inv_gamma_distr(x))
+  } else if (beautier::is_laplace_distr(x)) {
+    return(beautier::is_init_laplace_distr(x))
+  } else if (beautier::is_log_normal_distr(x)) {
+    return(beautier::is_init_log_normal_distr(x))
+  } else if (beautier::is_normal_distr(x)) {
+    return(beautier::is_init_normal_distr(x))
+  } else if (beautier::is_one_div_x_distr(x)) {
+    return(beautier::is_init_one_div_x_distr(x))
+  } else if (beautier::is_poisson_distr(x)) {
+    return(beautier::is_init_poisson_distr(x))
   } else {
-    testit::assert(is_uniform_distr(x)) # nolint beautier function
-    return(is_init_uniform_distr(x))  # nolint beautier function call
+    testit::assert(beautier::is_uniform_distr(x))
+    return(beautier::is_init_uniform_distr(x))
   }
 }
 
@@ -41,11 +41,12 @@ is_init_distr <- function(
 #'   initialized beta distribution object
 #' @return TRUE if x is an initialized beta distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_beta_distr <- function(
   x
 ) {
-  testit::assert(is_beta_distr(x)) # nolint beautier function
-  !is_one_na(x$alpha$id) && !is_one_na(x$beta$id) # nolint beautier function
+  testit::assert(beautier::is_beta_distr(x))
+  !beautier::is_one_na(x$alpha$id) && !beautier::is_one_na(x$beta$id)
 }
 
 #' Determine if x is an initialized exponential distribution object
@@ -54,24 +55,25 @@ is_init_beta_distr <- function(
 #'   initialized exponential distribution object
 #' @return TRUE if x is an initialized exponential distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_exp_distr <- function(
   x
 ) {
-  testit::assert(is_exp_distr(x)) # nolint beautier function
-  !is_one_na(x$mean$id) # nolint beautier function
+  testit::assert(beautier::is_exp_distr(x))
+  !beautier::is_one_na(x$mean$id)
 }
 
-
 #' Determine if x is an initialized gamma distribution object
 #' @param x the object to check if it is an
 #'   initialized gamma distribution object
 #' @return TRUE if x is an initialized gamma distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_gamma_distr <- function(
   x
 ) {
-  testit::assert(is_gamma_distr(x)) # nolint beautier function
-  !is_one_na(x$alpha$id) && !is_one_na(x$beta$id) # nolint beautier function
+  testit::assert(beautier::is_gamma_distr(x))
+  !beautier::is_one_na(x$alpha$id) && !beautier::is_one_na(x$beta$id)
 }
 
 #' Determine if x is an initialized inverse-gamma distribution
@@ -80,11 +82,12 @@ is_init_gamma_distr <- function(
 #'   initialized inverse-gamma distribution
 #' @return TRUE if x is an initialized inverse-gamma distribution
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_inv_gamma_distr <- function(
   x
 ) {
-  testit::assert(is_inv_gamma_distr(x)) # nolint beautier function
-  !is_one_na(x$alpha$id) && !is_one_na(x$beta$id) # nolint beautier function
+  testit::assert(beautier::is_inv_gamma_distr(x))
+  !beautier::is_one_na(x$alpha$id) && !beautier::is_one_na(x$beta$id)
 }
 
 #' Determine if x is an initialized Laplace distribution
@@ -93,11 +96,12 @@ is_init_inv_gamma_distr <- function(
 #'   initialized Laplace distribution
 #' @return TRUE if x is an initialized Laplace distribution
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_laplace_distr <- function(
   x
 ) {
-  testit::assert(is_laplace_distr(x)) # nolint beautier function
-  !is_one_na(x$mu$id) && !is_one_na(x$scale$id) # nolint beautier function
+  testit::assert(beautier::is_laplace_distr(x))
+  !beautier::is_one_na(x$mu$id) && !beautier::is_one_na(x$scale$id)
 }
 
 #' Determine if x is an initialized log_normal distribution object
@@ -106,11 +110,12 @@ is_init_laplace_distr <- function(
 #'   initialized log_normal distribution object
 #' @return TRUE if x is an initialized log_normal distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_log_normal_distr <- function(
   x
 ) {
-  testit::assert(is_log_normal_distr(x)) # nolint beautier function
-  !is_one_na(x$m$id) && !is_one_na(x$s$id) # nolint beautier function
+  testit::assert(beautier::is_log_normal_distr(x))
+  !beautier::is_one_na(x$m$id) && !beautier::is_one_na(x$s$id)
 }
 
 #' Determine if x is an initialized normal distribution object
@@ -119,11 +124,12 @@ is_init_log_normal_distr <- function(
 #'   initialized normal distribution object
 #' @return TRUE if x is an initialized normal distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_normal_distr <- function(
   x
 ) {
-  testit::assert(is_normal_distr(x)) # nolint beautier function
-  !is_one_na(x$mean$id) && !is_one_na(x$sigma$id) # nolint beautier function
+  testit::assert(beautier::is_normal_distr(x))
+  !beautier::is_one_na(x$mean$id) && !beautier::is_one_na(x$sigma$id)
 }
 
 #' Determine if x is an initialized one_div_x distribution object
@@ -132,10 +138,11 @@ is_init_normal_distr <- function(
 #'   initialized one_div_x distribution object
 #' @return TRUE if x is an initialized one_div_x distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_one_div_x_distr <- function(
   x
 ) {
-  testit::assert(is_one_div_x_distr(x)) # nolint beautier function
+  testit::assert(beautier::is_one_div_x_distr(x))
   TRUE
 }
 
@@ -145,11 +152,12 @@ is_init_one_div_x_distr <- function(
 #'   initialized Poisson distribution object
 #' @return TRUE if x is an initialized Poisson distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_poisson_distr <- function(
   x
 ) {
-  testit::assert(is_poisson_distr(x)) # nolint beautier function
-  !is_one_na(x$lambda$id) # nolint beautier function
+  testit::assert(beautier::is_poisson_distr(x))
+  !beautier::is_one_na(x$lambda$id)
 }
 
 #' Determine if x is an initialized uniform distribution object
@@ -158,9 +166,10 @@ is_init_poisson_distr <- function(
 #'   initialized uniform distribution object
 #' @return TRUE if x is an initialized uniform distribution object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_uniform_distr <- function(
   x
 ) {
-  testit::assert(is_uniform_distr(x)) # nolint beautier function
+  testit::assert(beautier::is_uniform_distr(x))
   TRUE
 }
