@@ -21,12 +21,12 @@ mrca_prior_to_xml_prior_distr <- function( # nolint beautier function
   has_non_strict_clock_model = FALSE,
   taxa_names_with_ids = NULL
 ) {
-  testit::assert(is_mrca_prior(mrca_prior)) # nolint beautier function
+  testit::assert(beautier::is_mrca_prior(mrca_prior))
   text <- NULL
   if (!has_non_strict_clock_model && # nolint beautier function
-      !is_one_na(mrca_prior$mrca_distr) # nolint beautier function
+      !beautier::is_one_na(mrca_prior$mrca_distr)
   ) {
-    testit::assert(!is_one_na(mrca_prior$alignment_id)) # nolint beautier function
+    testit::assert(!beautier::is_one_na(mrca_prior$alignment_id))
     text <- c(
       text,
       paste0(
@@ -37,11 +37,10 @@ mrca_prior_to_xml_prior_distr <- function( # nolint beautier function
     )
     text <- c(
       text,
-      indent( # nolint beautier function
+      beautier::indent(
         distr_to_xml(create_uniform_distr( # nolint beautier function
           id = mrca_prior$clock_prior_distr_id)
-        ),
-        n_spaces = 4
+        )
       )
     )
     text <- c(text, paste0("</prior>"))
@@ -54,7 +53,7 @@ mrca_prior_to_xml_prior_distr <- function( # nolint beautier function
   if (mrca_prior$is_monophyletic) {
     opening_tag <- paste0(opening_tag, "monophyletic=\"true\" ")
   }
-  testit::assert(!is_one_na(mrca_prior$alignment_id)) # nolint beautier function
+  testit::assert(!beautier::is_one_na(mrca_prior$alignment_id))
   opening_tag <- paste0(
     opening_tag, "tree=\"@Tree.t:", mrca_prior$alignment_id, "\">"
   )
@@ -62,16 +61,18 @@ mrca_prior_to_xml_prior_distr <- function( # nolint beautier function
   text <- c(text, opening_tag)
   text <- c(
     text,
-    indent( # nolint beautier function
+    beautier::indent(
       mrca_prior_to_xml_taxonset( # nolint beautier function
         mrca_prior,
         taxa_names_with_ids
-      ),
-      n_spaces = 4
+      )
     )
   )
-  if (is_distr(mrca_prior$mrca_distr)) { # nolint beautier function
-    text <- c(text, indent(distr_to_xml(mrca_prior$mrca_distr), n_spaces = 4)) # nolint beautier function
+  if (beautier::is_distr(mrca_prior$mrca_distr)) {
+    text <- c(
+      text,
+      beautier::indent(distr_to_xml(mrca_prior$mrca_distr))
+    )
   }
   text <- c(text, paste0("</distribution>"))
 
