@@ -8,13 +8,13 @@ mrca_prior_to_xml_state <- function(
   mrca_prior,
   has_non_strict_clock_model = FALSE
 ) {
-  testit::assert(is_mrca_prior(mrca_prior)) # nolint beautier function
+  testit::assert(beautier::is_mrca_prior(mrca_prior))
   if (mrca_prior$is_monophyletic == FALSE &&
-      is_one_na(mrca_prior$mrca_distr)) return(NULL) # nolint beautier function
+      beautier::is_one_na(mrca_prior$mrca_distr)) return(NULL)
   if (mrca_prior$is_monophyletic == TRUE &&
-    is_one_na(mrca_prior$mrca_distr)) return(NULL) # nolint beautier function
+    beautier::is_one_na(mrca_prior$mrca_distr)) return(NULL)
   if (!has_non_strict_clock_model) {
-    testit::assert(!is_one_na(mrca_prior$alignment_id)) # nolint beautier function
+    testit::assert(!beautier::is_one_na(mrca_prior$alignment_id))
     paste0(
       "<parameter ",
       "id=\"clockRate.c:", mrca_prior$alignment_id, "\" ",
