@@ -14,24 +14,25 @@ mrca_prior_to_xml_tracelog <- function( # nolint beautier function
   mrca_prior,
   tipdates_filename = NA
 ) {
-  testit::assert(is_mrca_prior(mrca_prior)) # nolint beautier function
+  testit::assert(beautier::is_mrca_prior(mrca_prior))
   if (length(mrca_prior) == 1 &&
-      is_one_na(mrca_prior) && # nolint beautier function
-      is_one_na(tipdates_filename)) { # nolint beautier function
+      beautier::is_one_na(mrca_prior) &&
+      beautier::is_one_na(tipdates_filename)
+  ) {
     return(NULL)
   }
 
   text <- NULL
-  if (!is_one_na(mrca_prior)) { # nolint beautier function
+  if (!beautier::is_one_na(mrca_prior)) {
     text <- c(text, paste0("<log idref=\"", mrca_prior$name, ".prior\"/>")) # nolint this is no absolute path
   }
 
   if (
     (
-      is_strict_clock_model(clock_models[[1]]) &&
-      is_mrca_prior_with_distr(mrca_prior)
+      beautier::is_strict_clock_model(clock_models[[1]]) &&
+      beautier::is_mrca_prior_with_distr(mrca_prior)
     ) ||
-      !is_one_na(tipdates_filename) # nolint beautier function
+      !beautier::is_one_na(tipdates_filename)
   ) {
     text <- c(
       text,
