@@ -2,7 +2,7 @@
 #' @inheritParams default_params_doc
 #' @return lines of XML text
 #' @seealso the complete tracelog section is created
-#'   by \code{\link{create_beast2_input_tracelog}}
+#'   by \code{\link{create_tracelog_xml}}
 #' @examples
 #' # <logger id="tracelog" ...>
 #' #'   # Here
@@ -14,7 +14,7 @@ mrca_priors_to_xml_tracelog <- function(
   mrca_priors,
   tipdates_filename = NA
 ) {
-  testit::assert(are_mrca_priors(mrca_priors)) # nolint beautier function
+  testit::assert(beautier::are_mrca_priors(mrca_priors))
   text <- NULL
 
   for (mrca_prior in mrca_priors) {
