@@ -4,62 +4,64 @@
 #' @return the parameter as XML text
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#'   xml <- beautier:::parameter_to_xml(create_alpha_param(id = 1))
-#'   testit::assert(length(xml) == 1)
-#'   testit::assert(nchar(xml) > 1)
-#' @noRd
+#' library(testthat)
+#'
+#' xml <- beautier:::parameter_to_xml(create_alpha_param(id = 1))
+#' expect_equal(length(xml), 1)
+#' expect_true(nchar(xml) > 1)
+#' @export
 parameter_to_xml <- function(
   parameter
 ) {
   text <- NULL
   id <- parameter$id
-  if (!is_id(id)) { # nolint beautier function
+  if (!beautier::is_id(id)) {
     stop("parameter must have an ID")
   }
-  testit::assert(!is_one_na(id)) # nolint beautier function
-  if (is_one_na(parameter$value)) { # nolint beautier function
+  testit::assert(!beautier::is_one_na(id))
+  if (beautier::is_one_na(parameter$value)) {
     stop("parameter must have a value")
   }
-  if (is_alpha_param(parameter)) {
+  if (beautier::is_alpha_param(parameter)) {
     text <- c(text, parameter_to_xml_alpha(parameter)) # nolint beautier function
-  } else if (is_beta_param(parameter)) {
+  } else if (beautier::is_beta_param(parameter)) {
     text <- c(text, parameter_to_xml_beta(parameter)) # nolint beautier function
-  } else if (is_clock_rate_param(parameter)) {
+  } else if (beautier::is_clock_rate_param(parameter)) {
     text <- c(text, parameter_to_xml_clock_rate(parameter)) # nolint beautier function
-  } else if (is_kappa_1_param(parameter)) {
+  } else if (beautier::is_kappa_1_param(parameter)) {
     text <- c(text, parameter_to_xml_kappa_1(parameter)) # nolint beautier function
-  } else if (is_kappa_2_param(parameter)) {
+  } else if (beautier::is_kappa_2_param(parameter)) {
     text <- c(text, parameter_to_xml_kappa_2(parameter)) # nolint beautier function
-  } else if (is_lambda_param(parameter)) {
+  } else if (beautier::is_lambda_param(parameter)) {
     text <- c(text, parameter_to_xml_lambda(parameter)) # nolint beautier function
-  } else if (is_m_param(parameter)) {
+  } else if (beautier::is_m_param(parameter)) {
     text <- c(text, parameter_to_xml_m(parameter)) # nolint beautier function
-  } else if (is_mean_param(parameter)) {
+  } else if (beautier::is_mean_param(parameter)) {
     text <- c(text, parameter_to_xml_mean(parameter)) # nolint beautier function
-  } else if (is_mu_param(parameter)) {
+  } else if (beautier::is_mu_param(parameter)) {
     text <- c(text, parameter_to_xml_mu(parameter)) # nolint beautier function
-  } else if (is_rate_ac_param(parameter)) {
+  } else if (beautier::is_rate_ac_param(parameter)) {
     text <- c(text, parameter_to_xml_rate_ac(parameter)) # nolint beautier function
-  } else if (is_rate_ag_param(parameter)) {
+  } else if (beautier::is_rate_ag_param(parameter)) {
     text <- c(text, parameter_to_xml_rate_ag(parameter)) # nolint beautier function
-  } else if (is_rate_at_param(parameter)) {
+  } else if (beautier::is_rate_at_param(parameter)) {
     text <- c(text, parameter_to_xml_rate_at(parameter)) # nolint beautier function
-  } else if (is_rate_cg_param(parameter)) {
+  } else if (beautier::is_rate_cg_param(parameter)) {
     text <- c(text, parameter_to_xml_rate_cg(parameter)) # nolint beautier function
-  } else if (is_rate_ct_param(parameter)) {
+  } else if (beautier::is_rate_ct_param(parameter)) {
     text <- c(text, parameter_to_xml_rate_ct(parameter)) # nolint beautier function
-  } else if (is_rate_gt_param(parameter)) {
+  } else if (beautier::is_rate_gt_param(parameter)) {
     text <- c(text, parameter_to_xml_rate_gt(parameter)) # nolint beautier function
-  } else if (is_s_param(parameter)) {
+  } else if (beautier::is_s_param(parameter)) {
     text <- c(text, parameter_to_xml_s(parameter)) # nolint beautier function
-  } else if (is_scale_param(parameter)) {
+  } else if (beautier::is_scale_param(parameter)) {
     text <- c(text, parameter_to_xml_scale(parameter)) # nolint beautier function
   } else {
     # This assert will also fail for new parameter types
-    testit::assert(is_sigma_param(parameter)) # nolint beautier function
+    testit::assert(beautier::is_sigma_param(parameter)) # nolint beautier function
     text <- c(text, parameter_to_xml_sigma(parameter)) # nolint beautier function
   }
-  testit::assert(is_xml(text)) # nolint
+  testit::assert(beautier::is_xml(text))
   text
 }
 
@@ -73,9 +75,9 @@ parameter_to_xml <- function(
 parameter_to_xml_alpha <- function(
   parameter
 ) {
-  testit::assert(is_alpha_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_alpha_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -97,9 +99,9 @@ parameter_to_xml_alpha <- function(
 parameter_to_xml_beta <- function(
   parameter
 ) {
-  testit::assert(is_beta_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_beta_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -121,9 +123,9 @@ parameter_to_xml_beta <- function(
 parameter_to_xml_clock_rate <- function(
   parameter
 ) {
-  testit::assert(is_clock_rate_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_clock_rate_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -146,9 +148,9 @@ parameter_to_xml_clock_rate <- function(
 parameter_to_xml_kappa_1 <- function(
   parameter
 ) {
-  testit::assert(is_kappa_1_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_kappa_1_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   paste0("<parameter id=\"kappa1.s:", id, "\" ",
     "lower=\"", parameter$lower, "\" ",
     "name=\"stateNode\">", parameter$value, "</parameter>"
@@ -165,9 +167,9 @@ parameter_to_xml_kappa_1 <- function(
 parameter_to_xml_kappa_2 <- function(
   parameter
 ) {
-  testit::assert(is_kappa_2_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_kappa_2_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   paste0("<parameter id=\"kappa2.s:", id, "\" ",
     "lower=\"", parameter$lower, "\" ",
     "name=\"stateNode\">", parameter$value, "</parameter>"
@@ -186,9 +188,9 @@ parameter_to_xml_kappa_2 <- function(
 parameter_to_xml_lambda <- function(
   parameter
 ) {
-  testit::assert(is_lambda_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_lambda_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   paste0(
     "<parameter ",
     "id=\"RealParameter.", id, "\" ",
@@ -207,9 +209,9 @@ parameter_to_xml_lambda <- function(
 parameter_to_xml_m <- function(
   parameter
 ) {
-  testit::assert(is_m_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_m_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -231,9 +233,9 @@ parameter_to_xml_m <- function(
 parameter_to_xml_mean <- function(
   parameter
 ) {
-  testit::assert(is_mean_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_mean_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -255,9 +257,9 @@ parameter_to_xml_mean <- function(
 parameter_to_xml_mu <- function(
   parameter
 ) {
-  testit::assert(is_mu_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_mu_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -282,9 +284,9 @@ parameter_to_xml_rate_ac <- function(
   which_name = "state_node"
 ) {
   testit::assert(which_name %in% c("state_node", "rate_name"))
-  testit::assert(is_rate_ac_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_rate_ac_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   value <- parameter$value
   lower <- parameter$lower
   line <- paste0("<parameter id=\"rateAC.s:", id, "\"")
@@ -314,9 +316,9 @@ parameter_to_xml_rate_ag <- function(
   which_name = "state_node"
 ) {
   testit::assert(which_name %in% c("state_node", "rate_name"))
-  testit::assert(is_rate_ag_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_rate_ag_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   value <- parameter$value
   lower <- parameter$lower
   line <- paste0("<parameter id=\"rateAG.s:", id, "\"")
@@ -346,9 +348,9 @@ parameter_to_xml_rate_at <- function(
   which_name = "state_node"
 ) {
   testit::assert(which_name %in% c("state_node", "rate_name"))
-  testit::assert(is_rate_at_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_rate_at_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   value <- parameter$value
   lower <- parameter$lower
   line <- paste0("<parameter id=\"rateAT.s:", id, "\"")
@@ -378,9 +380,9 @@ parameter_to_xml_rate_cg <- function(
   which_name = "state_node"
 ) {
   testit::assert(which_name %in% c("state_node", "rate_name"))
-  testit::assert(is_rate_cg_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_rate_cg_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   value <- parameter$value
   lower <- parameter$lower
   line <- paste0("<parameter id=\"rateCG.s:", id, "\"")
@@ -410,9 +412,9 @@ parameter_to_xml_rate_ct <- function(
   which_name = "state_node"
 ) {
   testit::assert(which_name %in% c("state_node", "rate_name"))
-  testit::assert(is_rate_ct_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_rate_ct_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   value <- parameter$value
   lower <- parameter$lower
   line <- paste0("<parameter id=\"rateCT.s:", id, "\"")
@@ -442,9 +444,9 @@ parameter_to_xml_rate_gt <- function(
   which_name = "state_node"
 ) {
   testit::assert(which_name %in% c("state_node", "rate_name"))
-  testit::assert(is_rate_gt_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_rate_gt_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   value <- parameter$value
   lower <- parameter$lower
   line <- paste0("<parameter id=\"rateGT.s:", id, "\"")
@@ -471,9 +473,9 @@ parameter_to_xml_rate_gt <- function(
 parameter_to_xml_s <- function(
   parameter
 ) {
-  testit::assert(is_s_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_s_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   value <- parameter$value
@@ -484,11 +486,11 @@ parameter_to_xml_s <- function(
       "id=\"RealParameter.", id, "\" ",
       "estimate=\"", estimate, "\""
     )
-  if (!is_one_na(lower)) { # nolint beautier function
+  if (!beautier::is_one_na(lower)) {
     text <- paste0(text, " lower=\"", lower, "\"")
   }
   text <- paste0(text, " name=\"S\"")
-  if (!is_one_na(upper)) { # nolint beautier function
+  if (!beautier::is_one_na(upper)) {
     upper_txt <- upper
     if (is.infinite(upper)) {
       upper_txt <- "Infinity"
@@ -509,9 +511,9 @@ parameter_to_xml_s <- function(
 parameter_to_xml_scale <- function(
   parameter
 ) {
-  testit::assert(is_scale_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_scale_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
@@ -533,9 +535,9 @@ parameter_to_xml_scale <- function(
 parameter_to_xml_sigma <- function(
   parameter
 ) {
-  testit::assert(is_sigma_param(parameter)) # nolint beautier function
+  testit::assert(beautier::is_sigma_param(parameter))
   id <- parameter$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   testit::assert(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   paste0(
