@@ -7,7 +7,7 @@
 rnd_phylo_to_xml_init <- function(
   id
 ) {
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
   text <- NULL
   text <- c(text, paste0("<init id=\"RandomTree.t:", id,
     "\" spec=\"beast.evolution.tree.RandomTree\" estimate=\"false\"",
