@@ -8,14 +8,14 @@ tree_prior_to_xml_operators <- function(
   tree_prior,
   fixed_crown_age = FALSE
 ) {
-  testit::assert(is_tree_prior(tree_prior)) # nolint beautier function
+  testit::assert(beautier::is_tree_prior(tree_prior))
   id <- tree_prior$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
 
   text <- NULL
   operator_id_pre <- get_operator_id_pre(tree_prior) # nolint beautier function
 
-  if (is_bd_tree_prior(tree_prior)) { # nolint beautier function
+  if (beautier::is_bd_tree_prior(tree_prior)) {
     text <- c(text, paste0("<operator id=\"BirthRateScaler.t:",
       id, "\" spec=\"ScaleOperator\" parameter=\"@BDBirthRate.t:",
       id, "\" scaleFactor=\"0.75\" weight=\"3.0\"/>")) # nolint this is no absolute path
@@ -23,11 +23,11 @@ tree_prior_to_xml_operators <- function(
       id,
       "\" spec=\"ScaleOperator\" parameter=\"@BDDeathRate.t:",
       id, "\" scaleFactor=\"0.75\" weight=\"3.0\"/>")) # nolint this is no absolute path
-  } else if (is_ccp_tree_prior(tree_prior)) { # nolint beautier function
+  } else if (beautier::is_ccp_tree_prior(tree_prior)) {
     text <- c(text, paste0("<operator id=\"PopSizeScaler.t:",
       id, "\" spec=\"ScaleOperator\" parameter=\"@popSize.t:", id,
       "\" scaleFactor=\"0.75\" weight=\"3.0\"/>")) # nolint this is no absolute path
-  } else if (is_cbs_tree_prior(tree_prior)) { # nolint beautier function
+  } else if (beautier::is_cbs_tree_prior(tree_prior)) {
     text <- c(text, paste0("<operator id=\"popSizesScaler.t:", id, "\" ",
       "spec=\"ScaleOperator\" parameter=\"@bPopSizes.t:", id, "\" ",
       "scaleFactor=\"0.75\" weight=\"15.0\"/>")) # nolint this is no absolute path
@@ -36,7 +36,7 @@ tree_prior_to_xml_operators <- function(
     text <- c(text, paste0("    <intparameter ",
       "idref=\"bGroupSizes.t:", id, "\"/>")) # nolint this is no absolute path
     text <- c(text, paste0("</operator>"))
-  } else if (is_cep_tree_prior(tree_prior)) { # nolint beautier function
+  } else if (beautier::is_cep_tree_prior(tree_prior)) {
     text <- c(text, paste0("<operator id=\"ePopSizeScaler.t:", id, "\" ",
       "spec=\"ScaleOperator\" parameter=\"@ePopSize.t:", id, "\" ",
       "scaleFactor=\"0.75\" weight=\"3.0\"/>")) # nolint this is no absolute path
@@ -46,7 +46,7 @@ tree_prior_to_xml_operators <- function(
       "weight=\"3.0\" windowSize=\"1.0\"/>")) # nolint this is no absolute path
   } else {
     # Will fail on unimplemented tree priors
-    testit::assert(is_yule_tree_prior(tree_prior)) # nolint beautier function
+    testit::assert(beautier::is_yule_tree_prior(tree_prior))
 
     text <- c(text,
       paste0(
