@@ -7,20 +7,20 @@
 tree_prior_to_xml_state <- function(
   tree_prior
 ) {
-  testit::assert(is_tree_prior(tree_prior)) # nolint beautier function
+  testit::assert(beautier::is_tree_prior(tree_prior))
   id <- tree_prior$id
-  testit::assert(is_id(id)) # nolint beautier function
+  testit::assert(beautier::is_id(id))
 
   text <- NULL
-  if (is_bd_tree_prior(tree_prior)) { # nolint beautier function
+  if (beautier::is_bd_tree_prior(tree_prior)) {
     text <- c(text, paste0("<parameter id=\"BDBirthRate.t:", id, "\" ",
       "lower=\"0.0\" name=\"stateNode\" upper=\"10000.0\">1.0</parameter>"))
     text <- c(text, paste0("<parameter id=\"BDDeathRate.t:", id, "\" ",
       "lower=\"0.0\" name=\"stateNode\" upper=\"1.0\">0.5</parameter>"))
-  } else if (is_ccp_tree_prior(tree_prior)) { # nolint beautier function
+  } else if (beautier::is_ccp_tree_prior(tree_prior)) {
     text <- c(text, paste0("<parameter id=\"popSize.t:", id, "\" ",
       "name=\"stateNode\">0.3</parameter>"))
-  } else if (is_cbs_tree_prior(tree_prior)) { # nolint beautier function
+  } else if (beautier::is_cbs_tree_prior(tree_prior)) {
     text <- c(text, paste0("<parameter id=\"bPopSizes.t:", id, "\" ",
       "dimension=\"5\" lower=\"0.0\" name=\"stateNode\" ",
       "upper=\"380000.0\">380.0</parameter>"))
@@ -32,13 +32,13 @@ tree_prior_to_xml_state <- function(
         "dimension=\"", tree_prior$group_sizes_dimension, "\">1</stateNode>"
       )
     )
-  } else if (is_cep_tree_prior(tree_prior)) { # nolint beautier function
+  } else if (beautier::is_cep_tree_prior(tree_prior)) {
     text <- c(text, paste0("<parameter id=\"ePopSize.t:", id, "\" ",
       "name=\"stateNode\">0.3</parameter>"))
     text <- c(text, paste0("<parameter id=\"growthRate.t:", id, "\" ",
       "name=\"stateNode\">3.0E-4</parameter>"))
   } else {
-    testit::assert(is_yule_tree_prior(tree_prior)) # nolint beautier function
+    testit::assert(beautier::is_yule_tree_prior(tree_prior))
       text <- c(text, paste0("<parameter ", "id=\"birthRate.t:", id, "\" ",
         "name=\"stateNode\">1.0</parameter>"))
   }
