@@ -9,7 +9,7 @@ tree_priors_to_xml_operators <- function(
   fixed_crown_ages = rep(FALSE, times = length(tree_priors))
 ) {
 
-  testit::assert(are_tree_priors(tree_priors)) # nolint beautier function
+  testit::assert(beautier::are_tree_priors(tree_priors))
   testit::assert(is.logical(fixed_crown_ages))
   testit::assert(length(tree_priors) == length(fixed_crown_ages))
 
