@@ -8,7 +8,7 @@
 tree_priors_to_xml_state <- function(
   tree_priors
 ) {
-  testit::assert(are_tree_priors(tree_priors)) # nolint beautier function
+  testit::assert(beautier::are_tree_priors(tree_priors))
 
   text <- NULL
   for (tree_prior in tree_priors) {
